#define _VERSION_ "V1.0.0"
/************************************************************************
*
* SignalTestJig.c
*
* Source code by DAXaCK Circuits4Tracks 06-11-2020
* Version 1.00 - November 6, 2020
*************************************************************************/
#include <pic.h>
#include "PilotLight.h"
#define _XTAL_FREQ			4e6			// needed for __delay_ms()

// Input Macros
#define CommonAnode		RB0
#define ThreeLight		RB1

/*************************************************************************
*                        Configuration Word Bits
*************************************************************************/
#pragma config DEBUG =		1		// In-Circuit Debugger disabled
#pragma config LVP =		0		// RB3 is digital I/O
#pragma config IESO =		0		// Internal/External Switchover mode is disabled
#pragma config BOREN =		0b00	// Brown-out Reset disabled
#pragma config CPD =		0		// Data memory code protection is enabled
#pragma config CP =			0		// Program memory code protection is enabled
#pragma config MCLRE =		0		// MCLR/VPP pin function is digital input
#pragma config PWRTE =		1		// Power-up Timer disabled
#pragma config WDTE =		0		// Watchdog Timer disabled
#pragma config FOSC =		0b100	// Oscillator Selection; INTOSC oscillator; I/O function RA6 and RA7

// CONFIG2
#pragma config WRT =		0b11	// Flash Memory Self-Write Protection off
#pragma config BOR4V =		0		// Brown-out Reset Voltage (Vbor), low trip point selected (2.1 V)


/*************************************************************************
*                         ID Locations: "1.00"
*************************************************************************/
#pragma config IDLOC0 = 49, IDLOC1 = 46, IDLOC2 = 48, IDLOC3 = 48



void Initialize( void )
{
	/*********************************
	* Setup Oscillator Control
	* IRCF   = 4 MHz    = 110
	* SCS    = FOSC     = 0
	*********************************/
	OSCCON =		0b01100000;

	/*********************************
	* Port B Settings
	* PORTB:	no need to initialize - all used only for inputs
	* TRISB:	POR value used (all inputs)
	* ANSELH:	Set for all as digital input
	* WPUB:		POR value used (all pull-ups enabled)
	*********************************/
	ANSELH =		0;
	WPUB =			0xFF;				// Port B internal pull-ups enabled

	/*********************************
	* Port A Settings
	* PORTA:	Initialize Bits 0, 1, and 2 all to value of RB0
	* TRISA:	Bits 0, 1, and 2 are outputs
	* ANSEL:	POR values acceptable (only using as outputs)
	*********************************/
	PORTA =			(unsigned)( CommonAnode ? 0b111 : 0b000 );
	TRISA =			0b11111000;			// Port A: bits 2-0 outputs

	/*********************************
	* Port C: set up by InitializePilotLight()
	* Port E Settings not used: POR values acceptable
	*********************************/
	INTCON =		0x00;				// Disable All Interrupts and clear flags
	InitializePilotLight();

	/***** Set interrupt flags *****/
	GIE =			1;					// Enable Global interrupts
	PEIE =			1;					// Enable Peripheral interrupts
}


void main( void )
{
	enum Outputs					{ eGreen, eRed, eYellow, nOutputs };
	static unsigned	ThreeLED[] =	{ 0b001, 0b010, 0b100 },
					TwoLED[] =		{ 0b001, 0b010, 0b011 },
					* Lookup;
	char			Output =	eGreen;

	Initialize();
	while( Output < nOutputs )
	{
		Lookup = ThreeLight ? ThreeLED : TwoLED;
		PORTA = Lookup[ Output ] ^ (unsigned)( CommonAnode ? 0b111 : 0b000 );
		__delay_ms( 1000 );
		if( ++Output >= nOutputs )
			Output = eGreen;
	}
}
